%define _buildid .12

%global py26nvr %{name}-python26-%{version}-%{release}
%global py26builddir %{_builddir}/%{py26nvr}
%global py26doc ../%{py26nvr}

%global py27nvr %{name}-python27-%{version}-%{release}
%global py27builddir %{_builddir}/%{py27nvr}
%global py27doc ../%{py27nvr}

Summary: Library providing the Gnome XSLT engine
Name: libxslt
Version: 1.1.28
Release: 5%{?_buildid}%{?dist}
License: MIT
Group: Development/Libraries
Source: ftp://xmlsoft.org/XSLT/libxslt-%{version}.tar.gz
URL: http://xmlsoft.org/XSLT/
BuildRequires: libxml2-devel >= 2.6.27
BuildRequires: libgcrypt-devel
BuildRequires: automake autoconf

# Fedora specific patches
Patch0: multilib.patch
Patch1: libxslt-1.1.26-utf8-docs.patch

# Amazon patches
Patch100: libxslt-dist-packages.patch

%description
This C library allows to transform XML files into other XML files
(or HTML, text, ...) using the standard XSLT stylesheet transformation
mechanism. To use it you need to have a version of libxml2 >= 2.6.27
installed. The xsltproc command is a command line interface to the XSLT engine

%package devel
Summary: Development files for %{name}
Group: Development/Libraries
Requires: libxslt = %{version}-%{release}
Requires: libgcrypt-devel


%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package python26
Summary: Python bindings for the libxslt library
Group: Development/Libraries
BuildRequires: python26-devel
BuildRequires: libxml2-python26
Requires: libxslt = %{version}-%{release}
Requires: libxml2-python26
Obsoletes: libxslt-python <= 1.1.28-5.9.amzn1
Provides: libxslt-python = %{version}-%{release}
Provides: libxslt-python%{?_isa} = %{version}-%{release}

%description python26
The libxslt-python26 package contains a module that permits applications
written in the Python 2.6 programming language to use the interface
supplied by the libxslt library to apply XSLT transformations.

This library allows to parse stylesheets, uses the libxml2-python26
to load and save XML and HTML files. Direct access to XPath and
the XSLT transformation context are possible to extend the XSLT language
with XPath functions written in Python.

%package python27
Summary: Python bindings for the libxslt library
Group: Development/Libraries
BuildRequires: python27-devel
BuildRequires: libxml2-python27
Requires: libxslt = %{version}-%{release}
Requires: libxml2-python27

%description python27
The libxslt-python27 package contains a module that permits applications
written in the Python 2.7 programming language to use the interface
supplied by the libxslt library to apply XSLT transformations.

This library allows to parse stylesheets, uses the libxml2-python27
to load and save XML and HTML files. Direct access to XPath and
the XSLT transformation context are possible to extend the XSLT language
with XPath functions written in Python.

%prep
%setup -q
%patch0 -p1
%patch1 -p1 -b .utf8

%patch100 -p1

# Now fix up the timestamps of patched docs files
# ChangeLog needs to be retouched before gzip as well
# since timestamp affects output
touch -r ChangeLog.utf8 ChangeLog
gzip -9 ChangeLog
touch -r ChangeLog.utf8 ChangeLog.gz
touch -r NEWS.utf8 NEWS

chmod 644 python/tests/*

%build
rm -rf %{py26builddir} %{py27builddir}
mkdir -p %{py26builddir} %{py27builddir}
cp -a * %{py26builddir}
cp -a * %{py27builddir}

%configure --disable-static --without-python
make %{?_smp_mflags}

pushd %{py26builddir}
find python/tests -name '*.py' -exec %{__python26_shebang} "{}" \+
export PYTHON=%{__python26}
%configure --disable-static
make %{_smp_mflags}
export PYTHON=
popd

pushd %{py27builddir}
find python/tests -name '*.py' -exec %{__python27_shebang} "{}" \+
export PYTHON=%{__python27}
%configure --disable-static
make %{_smp_mflags}
export PYTHON=
popd

%install
make install DESTDIR=$RPM_BUILD_ROOT INSTALL="install -p"

pushd %{py26builddir}
make \
  DESTDIR="$RPM_BUILD_ROOT" INSTALL="install -p" \
  EXAMPLE_DIR='%{_datadir}/doc/libxslt-python26-%{version}/examples' \
  DOCS="" \
  -C python install
popd

pushd %{py27builddir}
make \
  DESTDIR="$RPM_BUILD_ROOT" INSTALL="install -p" \
  EXAMPLE_DIR='%{_datadir}/doc/libxslt-python27-%{version}/examples' \
  DOCS="" \
  -C python install
popd

find $RPM_BUILD_ROOT -name '*.la' -exec rm -f {} ';'

# multiarch crazyness on timestamp differences
touch -m --reference=$RPM_BUILD_ROOT/%{_includedir}/libxslt/xslt.h $RPM_BUILD_ROOT/%{_bindir}/xslt-config

rm -rf $RPM_BUILD_ROOT%{_datadir}/doc/%{name}-%{version}

%check
make tests
pushd %{py26builddir}
make -C python tests PYTHON=%{__python26}
popd
pushd %{py27builddir}
make -C python tests PYTHON=%{__python27}
popd

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-, root, root,-)
%doc AUTHORS ChangeLog.gz NEWS README Copyright FEATURES
%doc %{_mandir}/man1/xsltproc.1*
%{_libdir}/lib*.so.*
%{_libdir}/libxslt-plugins
%{_bindir}/xsltproc

%files devel
%defattr(-, root, root,-)
%doc doc/libxslt-api.xml
%doc doc/libxslt-refs.xml
%doc doc/EXSLT/libexslt-api.xml
%doc doc/EXSLT/libexslt-refs.xml
%doc %{_mandir}/man3/libxslt.3*
%doc %{_mandir}/man3/libexslt.3*
%doc doc/*.html doc/html doc/*.gif doc/*.png
%doc doc/images
%doc doc/tutorial
%doc doc/tutorial2
%doc doc/EXSLT
%{_libdir}/lib*.so
%{_libdir}/*.sh
%{_datadir}/aclocal/libxslt.m4
%{_includedir}/*
%{_bindir}/xslt-config
%{_libdir}/pkgconfig/libxslt.pc
%{_libdir}/pkgconfig/libexslt.pc

%files python26
%defattr(-, root, root,-)
%{python26_sitearch}/libxslt.py*
%{python26_sitearch}/libxsltmod*
%doc %{py26doc}/python/libxsltclass.txt
%doc %{py26doc}/python/tests/*.py
%doc %{py26doc}/python/tests/*.xml
%doc %{py26doc}/python/tests/*.xsl

%files python27
%defattr(-, root, root,-)
%{python27_sitearch}/libxslt.py*
%{python27_sitearch}/libxsltmod*
%doc %{py27doc}/python/libxsltclass.txt
%doc %{py27doc}/python/tests/*.py
%doc %{py27doc}/python/tests/*.xml
%doc %{py27doc}/python/tests/*.xsl

%changelog
* Wed Mar 4 2015 Rodrigo Novo <rodarvus@amazon.de>
- Install python modules on dist-packages

* Wed Feb 18 2015 Ben Cressey <bcressey@amazon.com>
- build legacy python 2.6 module

* Sun Jan 25 2015 Ben Cressey <bcressey@amazon.com>
- build with system python

* Wed May 7 2014 Cristian Gafton <gafton@amazon.com>
- import source package RHEL7/libxslt-1.1.28-5.el7

* Fri Jan 24 2014 Daniel Mach <dmach@redhat.com> - 1.1.28-5
- Mass rebuild 2014-01-24

* Wed Jan 15 2014 Cristian Gafton <gafton@amazon.com>
- import source package RHEL7/libxslt-1.1.28-3.el7

* Fri Dec 27 2013 Daniel Mach <dmach@redhat.com> - 1.1.28-4
- Mass rebuild 2013-12-27

* Fri Jun 21 2013 Matthias Clasen <mclasen@redhat.com> - 1.1.28-3
- Don't ship api docs twice (they were included in both
  the main and the devel package, by accident (need to save
  space on the f19 live images)

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.28-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Nov 21 2012 Daniel Veillard <veillard@redhat.com> - 1.1.28-1
- upstream release of libxslt-1.1.28
- a few bug fixes and cleanups

* Tue Oct  9 2012 Daniel Veillard <veillard@redhat.com> - 1.1.27-2
- fix a regression in default namespace handling

* Fri Sep 14 2012 Cristian Gafton <gafton@amazon.com>
- import source package RHEL6/libxslt-1.1.26-2.el6_3.1

* Wed Sep 12 2012 Daniel Veillard <veillard@redhat.com> - 1.1.27-1
- upstream release of libxslt-1.1.27
- a lot of bug fixes and improvements

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.26-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.26-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Sun Mar 20 2011 Michel Salim <salimma@fedoraproject.org> - 1.1.26-8
- ChangeLog: fix character encoding
- Restore timestamps for patched documentation files

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.26-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Fri Dec 17 2010 Dan Horák <dan[at]danny.cz> - 1.1.26-6
- libexslt needs libgcrypt-devel via its pkgconfig file

* Thu Dec 2 2010 Cristian Gafton <gafton@amazon.com>
- import source package RHEL6/libxslt-1.1.26-2.el6

* Mon Oct 25 2010 Parag Nemade <paragn AT fedoraproject.org> - 1.1.26-5
- Patch from Paul Howarth for converting files to utf8 (#226088)

* Tue Oct 05 2010 Parag Nemade <paragn AT fedoraproject.org> - 1.1.26-4
- Merge-review cleanup (#226088)

* Wed Jul 21 2010 David Malcolm <dmalcolm@redhat.com> - 1.1.26-3
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Fri Jul 9 2010 Cristian Gafton <gafton@amazon.com>
- import source package RHEL6/libxslt-1.1.26-1.el6.1

* Mon May 24 2010 Tom "spot" Callaway <tcallawa@redhat.com> 1.1.26-2
- disable static libs

* Thu May 20 2010 Cristian Gafton <gafton@amazon.com>
- import source package RHEL5/libxslt-1.1.17-2.el5_2.2
- import source package RHEL5/libxslt-1.1.17-2.el5_1.1
- import source package RHEL5/libxslt-1.1.17-2
- added submodule prep for package libxslt

* Thu Sep 24 2009 Daniel Veillard <veillard@redhat.com> 1.1.26-1
- couple of bug fixes
- export a symbol needed by lxml

* Mon Sep 21 2009 Daniel Veillard <veillard@redhat.com> 1.1.25-2
- fix a locking bug in 1.1.25

* Thu Sep 17 2009 Daniel Veillard <veillard@redhat.com> 1.1.25-1
- release of 1.1.25
- Add API versioning  for libxslt shared library
- xsl:sort lang support using the locale
- many bug fixes

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.24-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.24-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sat Nov 29 2008 Ignacio Vazquez-Abrams <ivazqueznet+rpm@gmail.com> 1.1.24-3
- Rebuild for Python 2.6

* Wed Oct  8 2008 Daniel Veillard <veillard@redhat.com> 1.1.24-2.fc10
- CVE-2008-2935 fix

* Tue May 13 2008 Daniel Veillard <veillard@redhat.com> 1.1.24-1.fc10
- release of 1.1.24
- fixes a few bugs including the key initialization problem
- tentative fix for multiarch devel problems

* Mon Apr 28 2008 Daniel Veillard <veillard@redhat.com> 1.1.23-3.fc10
- and the previous patch was incomplte breaking the python bindings
  see 444317 and 444455

* Tue Apr 22 2008 Daniel Veillard <veillard@redhat.com> 1.1.23-2.fc10
- revert a key initialization patch from 1.1.23 which seems broken
  see rhbz#442097

* Tue Apr  8 2008 Daniel Veillard <veillard@redhat.com> 1.1.23-1.fc9
- upstream release 1.1.23
- bugfixes

* Wed Feb 20 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 1.1.22-2
- Autorebuild for GCC 4.3

* Thu Aug 23 2007 Daniel Veillard <veillard@redhat.com> 1.1.22-1
- upstream release 1.1.22 see http://xmlsoft.org/XSLT/news.html

* Tue Jun 12 2007 Daniel Veillard <veillard@redhat.com> 1.1.21-1
- upstream release 1.1.21 see http://xmlsoft.org/XSLT/news.html

* Thu Feb 15 2007 Adam Jackson <ajax@redhat.com>
- Add dist tag to Release to fix 6->7 upgrades.

* Wed Jan 17 2007 Daniel Veillard <veillard@redhat.com>
- upstream release 1.1.20 see http://xmlsoft.org/XSLT/news.html

* Thu Dec  7 2006 Jeremy Katz <katzj@redhat.com> - 1.1.19-2
- rebuild against python 2.5

* Wed Nov 29 2006 Daniel Veillard <veillard@redhat.com>
- upstream release 1.1.19 see http://xmlsoft.org/XSLT/news.html

* Thu Oct 26 2006 Daniel Veillard <veillard@redhat.com>
- upstream release 1.1.18 see http://xmlsoft.org/XSLT/news.html

* Wed Jul 12 2006 Jesse Keating <jkeating@redhat.com> - 1.1.17-1.1
- rebuild

* Tue Jun  6 2006 Daniel Veillard <veillard@redhat.com>
- upstream release 1.1.17 see http://xmlsoft.org/XSLT/news.html
